@@ -19,6 +19,12 @@ def parse_match_report(report_text: str) -> ParsedMatchReport:
         raw_date=match_info.raw_date,
         date=match_info.date,
         match_level=match_info.match_level,
+        platform=match_info.platform,
+        ps_product=match_info.ps_product,
+        ps_version=match_info.ps_version,
+        club_code=match_info.club_code,
+        club_name=match_info.club_name,
+        region=match_info.region,
         competitors=competitors,
         stages=stages,
         stage_scores=stage_scores,
